@@ -4,7 +4,7 @@
 #
 # For copyright and disclaimer see below.
 #
-# $Id: FileStore.pm,v 1.9 2010-01-07 21:52:14 ubuntu Exp $
+# $Id: FileStore.pm,v 1.7 2009-09-11 15:56:41 ubuntu Exp $
 #-----------------------------------------------------------------
 package SADI::FileStore;
 use SADI::Base;
@@ -20,7 +20,7 @@ use strict;
 
 # add versioning to this module
 use vars qw /$VERSION/;
-$VERSION = sprintf "%d.%02d", q$Revision: 1.9 $ =~ /: (\d+)\.(\d+)/;
+$VERSION = sprintf "%d.%02d", q$Revision: 1.7 $ =~ /: (\d+)\.(\d+)/;
 
 =head1 NAME
 
@@ -34,12 +34,12 @@ SADI::FileStore - A module for (add|get|delet)ing persistent data
 
  # create a new blank SADI FileStore object
  my $data = SADI::FileStore->new ();
-
+ 
  # create a new primed SADI File store object
  $data = SADI::FileStore->new (
      ServiceName => "HelloWorldService",
  );
-
+ 
  # get the service name
  my $name = $data->ServiceName;
  # set the service name
@@ -47,7 +47,7 @@ SADI::FileStore - A module for (add|get|delet)ing persistent data
 
  # create a unique id
  my $uid = $data->generate_uid();
-
+ 
  # store a persistent file
  $data->add($uid,"my value");
 
@@ -147,34 +147,14 @@ The name of the service that this FileStore will operate on
 
  Edward Kawas  (edward.kawas [at] gmail [dot] com)
 
-Copyright (c) 2009, Mark Wilkinson
-All rights reserved.
+Copyright (c) 2009 Edward Kawas. All Rights Reserved.
 
-Redistribution and use in source and binary forms, with or without modification,
-are permitted provided that the following conditions are met:
+This module is free software; you can redistribute it and/or modify
+it under the same terms as Perl itself.
 
-    * Redistributions of source code must retain the above copyright notice, 
-      this list of conditions and the following disclaimer.
-    * Redistributions in binary form must reproduce the above copyright notice,
-      this list of conditions and the following disclaimer in the documentation
-      and/or other materials provided with the distribution.
-    * Neither the name of the University of British Columbia nor the names of 
-      its contributors may be used to endorse or promote products derived from 
-      this software without specific prior written permission.
-
-THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND 
-ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED 
-WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. 
-IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, 
-INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
-BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR 
-PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
-WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
-ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY
-OF SUCH DAMAGE.
+This software is provided "as is" without warranty of any kind.
 
 =cut
-
 {
 	my %_allowed = (
 
