@@ -3,7 +3,7 @@
 # Author: Edward Kawas
 # For copyright and disclaimer see below.
 #
-# $Id: SADI.pm,v 1.36 2010-03-09 18:04:43 ubuntu Exp $
+# $Id: SADI.pm,v 1.21 2009-09-22 14:08:06 ubuntu Exp $
 #-----------------------------------------------------------------
 package SADI::SADI;
 use strict 'vars';
@@ -13,7 +13,7 @@ use vars qw{$VERSION};
 
 BEGIN {
 	use vars qw{@ISA @EXPORT @EXPORT_OK};
-	$VERSION = sprintf "%d.%02d", q$Revision: 1.36 $ =~ /: (\d+)\.(\d+)/;
+	$VERSION = sprintf "%d.%02d", q$Revision: 1.21 $ =~ /: (\d+)\.(\d+)/;
 	*SADI::SADI::VERSION = *VERSION;
 }
 
@@ -23,83 +23,25 @@ __END__
 
 =head1 NAME
 
-SADI - !!Look Here First!! Perl extension for the automatic generation of SADI web services
-
-=head2 Upgrading From Version 0.99.4
-
-Version 0.99.5 contains some neat new features and bug fixes! One of the added features is the ability to add unit test for your service.
-
-All that is needed to upgrade to 0.99.5 is for you to re-run the C<sadi-install.pl> script.  
-
-=head2 Upgrading From Version 0.99.2
-
-For those of you upgrading a previous SADISeS installation and using OWL2Perl modules, you will need to regenerate your datatypes.
-
-After careful consideration, it was determined that we could clean up the package names for generated owl entities.
-
-The easiest way to update your services is to do the following (assuming for a second
-that your home directory is /home/ubuntu/ and that you are using a *NIX machine):
-
-To update your implementation files, do something like:
-
-C<for i in `find /home/ubuntu/Perl-SADI/services/Service -type f -print`; do perl -pi -e 's|::owl::|::|g' $i; done> 
-
-If you are on windows, try the following (assuming that your home directory is C:\Users\ubuntu\):
-
-C<for /R %i in ("C:\Users\ubuntu\Perl-SADI\cgi\*") do perl -pi -e 's|::owl::|::|g' %i>
-
-Additionally, for those of you that pre-generate your asynchronous service base file (not default operation), you will need to re-generate your service basis.
-For each service that is affected, do a C<sadi-generate-service -B your_service_name>. 
-
-=head2 Upgrading From Version 0.99.1
-
-For those of you upgrading a previous SADISeS installation, you will need to
-decide if you want to remove the CGI entry scripts for your services and re-generate them.
-
-The reason for this is that the mime type header for SADI services has been changed to
-"application/rdf+xml", as per the W3C RDF spec. While this change makes your services
-more correct, it doesnt change how your services behave.
-
-The easiest way to update your services is to do the following (assuming for a second
-that your home directory is /home/ubuntu/ and that you are using a *NIX machine):
-
-To update your entry scripts, do something like:
-
-C<for i in `find /home/ubuntu/Perl-SADI/cgi -type f -print`; do perl -pi -e 's|text/xml|application/rdf\+xml|g' $i; done> 
-
-If you are on windows, try the following (assuming that your home directory is C:\Users\ubuntu\):
-
-C<for /R %i in ("C:\Users\ubuntu\Perl-SADI\cgi\*") do perl -pi -e 's|text/xml|application/rdf\+xml|g' %i>
+SADI - Perl extension for the automatic generation of SADI web services
 
 =head1 SYNOPSIS
 
-       # to get started, run the install script
-       sadi-install.pl
+  # to get started, run the install script
+  sadi-install.pl
 
-       # generate a service definition file, for example HelloSadiWorld
-       sadi-generate-services.pl -D HelloSadiWorld
+  # generate a service definition file, for example HelloSadiWorld
+  sadi-generate-services.pl -D HelloSadiWorld
 
-       # now you have to go and edit the definition file
-       # in Perl-SADI/definitions/HelloSadiWorld
-       # to point it to the various ontologies that your service uses
-       # once you have done that, then...
+  # generate a service implementation, for example HelloSadiWorld
+  sadi-generate-services.pl HelloSadiWorld
 
-       # generate a service implementation, based on this edited
-       # definitions file.  In this example, you would simply type:
+  # add your business logic to the module services/Service/HelloSadiWorld.pm
 
-       sadi-generate-services.pl HelloSadiWorld
+  # assuming that you deployed it, test the service (-g gets the service interface)
+  sadi-testing-service.pl -g http://localhost/cgi-bin/HelloSadiWorld
 
-       # now add your business logic to the module that was created in
-       # Perl-SADI/services/Service/HelloSadiWorld.pm
-
-       # finally, make a symbolic link from Perl-SADI/cgi/HelloSadiWorld to
-       # your cgi-bin/ directory to deploy your service.
-
-       # assuming that you deployed it, test the service (-g gets the service interface
-       # while -e allows you to send input data to the service)
-       sadi-testing-service.pl -g http://localhost/cgi-bin/HelloSadiWorld
-
-       # read the POD for more details!
+  # read the POD for more details!
 
 =head1 DESCRIPTION
 
@@ -225,7 +167,7 @@ or,
 C<sadi-generate-services.pl -D HelloSadiWorld>
 
 This will create a definition for your SADI service (in the E<lt>your-home-directoryE<gt>/Perl-SADI/definitions/ directory).
-
+ 
 Next create the implementation for the SADI service by doing:
 
 C<sadi-generate-services HelloSadiWorld>
@@ -358,6 +300,9 @@ The other modules needed are (all available from the CPAN):
 =item * Log::Log4perl 
 	- a wonderful port of the famous log4j Java logging system.
 
+=item * Template
+    - a modern Perl Template Toolkit, a really fascinating tool.
+
 =item * Config::Simple
      - for a simple service configuration
 
@@ -381,7 +326,7 @@ The other modules needed are (all available from the CPAN):
 
 =item * HTTP::Date 
     - for developing asynchronous moby services I<Optional>
-
+    
 =item *
     Template - for creating RDF, service and definition templates 
 
@@ -435,8 +380,6 @@ Created install directory &apos;/home/ubuntu/Perl-SADI&apos;.
 Created install directory &apos;/home/ubuntu/Perl-SADI/cgi&apos;.
 Created sample-resources directory &apos;/home/ubuntu/Perl-SADI/sample-resources&apos;.
 Created service defintions directory &apos;/home/ubuntu/Perl-SADI/definitions&apos;.
-Created service defintions directory &apos;/home/ubuntu/Perl-SADI/unittest&apos;.
-Created service defintions directory &apos;/home/ubuntu/Perl-SADI/xml&apos;.
 
 Log properties file created: &apos;/home/ubuntu/Perl-SADI/log4perl.properties&apos;.
 
@@ -455,14 +398,10 @@ All these things can be done manually, at any time. Installation script just mak
 	installing them, however. Perl has a CPAN mechanism in place to do 
 	that. The required modules are listed in requirements. Installation
 	stops if some module is not available.
-
+	
 	* It creates a directory called 'Perl-SADI' in your user directory.
 	Perl SADI will stop working if you move this directory because it 
 	contains vital configuration information inside it.
-	
-	* It creates sub directories in the 'Perl-SADI' directory for places
-	to store your service definitions, generated code, example service
-	input, etc.
 
     * It creates two empty log files Perl-SADI/services.log and
 	Perl-SADI/parser.log - unless they already exist. In any case,
@@ -496,9 +435,7 @@ Perl Moses generates Perl code. Actually, up to four pieces of the code:
 
 =head4 Perl Datatypes Representing OWL classes for SADI services
 
-SADISeS allows for easier implementation of SADI services by allowing you to use automatically generated PERL modules representing OWL classes in your service implementation.
-
-The Generated perl modules that represent OWL classes have their own constructors, contain getter and setters for their datatype properties, and even have range checking for object properties. While the generator isn't perfect, it will do the job in most cases; making your service provision much more simple.
+Actually, this is not done yet. Sorry!
 
 =cut
 
@@ -650,7 +587,7 @@ This script does not do much but gives you overview of your configuration and in
 =begin html
 
 <pre>
-Perl-SADI VERSION: 0.96
+Perl-SADI VERSION: 1.04
 
 Configuration
 -------------
@@ -725,40 +662,6 @@ Testing log messages (some may go only to a logfile):
 
 =cut
 
-=head4 sadi-generate-datatypes.pl
-
-This script is really important for those of you wishing to use PERL modules representing your OWL classes.
-
-Basically, this script reads your OWL file and processes all of the OWL classes and properties specified in that file. Once the processing is complete, PERL modules representing those classes and properties are either written to disk or displayed on screen.
-
-One obvious question is "B<where are these perl objects generated>"?
-
-You can always determine this after generation by looking in the log file - the message has the INFO level which means it is almost always logged. But, if you want to know in advance here are the rules:
-
-=over
-
-=item If there is a generators.outdir parameter in the configuration file, it is used. It defines the directory where OWL classes and properties are created.
-
-=item Otherwise, program is trying to find an existing directory named 'generated' anywhere in the @INC (a set of directories used by Perl to locate its modules).
-
-=item If it fails, it creates a new directory 'generated' in the "current" directory.
-
-=back
-
-You can use option I<-s> to get the generated result directly on the screen (in that case no file is created).
-
-To generate OWL classes and properties from a remote url, you would use the B<-u> option. This option sets the base URI for the OWL file to be the URL to the OWL file (if one didn't already exist).
-
-If the file you would like to generate classes and properties from resides on your disk, then you would use not specify any option. If the local file doesn't specify a base URI for the ontology, you can do this with the B<-b> flag. When the script executes, it will prompt you for a URI.
-
-More often than not, your ontology will contain import statements. If you wish to follow them, you need to set the B<-i> flag. This flag tells the script to process import statements, so make sure that you have an internet connection if the referenced files are located somewhere remote.  
-
-Like the other SADI scripts included in this distribution, you can access the script help page by running the script with the B<-h> flag.
-
-For more information on the perl OWL modules that were generated, read the perldoc for the class or property of interest!
-
-=cut
-
 =head4 sadi-generate-services.pl
 
 This is the most important script. You may use only the C<sadi-install.pl> and this one - and you will get all what you need. It generates services - all pieces belonging to services (except data types).
@@ -816,7 +719,7 @@ With options, you can generated other Perl SADI pieces:
    This is the first thing that you need to generate before generating a service implementation!<p/>
 
    Option <strong>-b</strong> generates <a href="#perl_modules_representing_bases_of_service_implementations">service bases</a>,
-
+   
    Option <strong>-S</strong> generates both <a href="#perl_modules_representing_bases_of_service_implementations">service bases</a> 
    and service implementations. This also influences how the service base will be used at run-time:  
         if it is already generated (with the -S option) there is no need to do it again in the run-time - therefore, the service implementation 
@@ -1228,7 +1131,7 @@ re-create it. Here is a whole script (for HelloSadiWorld):
 # It includes some hard-coded paths - they were added during the
 # generate service call.
 #
-# $Id: SADI.pm,v 1.36 2010-03-09 18:04:43 ubuntu Exp $
+# $Id: SADI.pm,v 1.21 2009-09-22 14:08:06 ubuntu Exp $
 # Contact: Edward Kawas &lt;edward.kawas@gmail.com&gt;
 # ---------------------------------------------------------------
 
@@ -1572,30 +1475,11 @@ Please visit the SADI website at L<http://sadiframework.org>!
 
 =head1 COPYRIGHT
 
-Copyright (c) 2009, Mark Wilkinson
-All rights reserved.
+Copyright (c) 2009 Edward Kawas.
 
-Redistribution and use in source and binary forms, with or without modification,
-are permitted provided that the following conditions are met:
+This module is free software; you can redistribute it and/or modify
+it under the same terms as Perl itself.
 
-    * Redistributions of source code must retain the above copyright notice, 
-      this list of conditions and the following disclaimer.
-    * Redistributions in binary form must reproduce the above copyright notice,
-      this list of conditions and the following disclaimer in the documentation
-      and/or other materials provided with the distribution.
-    * Neither the name of the University of British Columbia nor the names of 
-      its contributors may be used to endorse or promote products derived from 
-      this software without specific prior written permission.
-
-THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND 
-ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED 
-WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. 
-IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, 
-INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
-BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR 
-PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
-WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
-ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY
-OF SUCH DAMAGE.
+This software is provided "as is" without warranty of any kind.
 
 =cut
